"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const denormalize_1 = require("./denormalize");
const html_parser_1 = require("./html-parser");
const templates_1 = require("./templates");
function getHTMLInfo(html) {
    if (!html) {
        return { externalResources: [], file: null };
    }
    const { externalResources } = html_parser_1.default(html.content);
    return { externalResources, file: html };
}
function findMainFile(directory, mainFile, template) {
    if (directory[mainFile]) {
        return mainFile;
    }
    if (directory[templates_1.getMainFile(template)]) {
        return templates_1.getMainFile(template);
    }
    if (directory['src/index.js']) {
        return 'src/index.js';
    }
    if (directory['index.js']) {
        return 'index.js';
    }
    return mainFile || templates_1.getMainFile(template);
}
/**
 * Creates all relevant data for create a sandbox, like dependencies and which
 * files are in a sandbox
 *
 * @export SandboxObject
 * @param {Array<Module>} files
 * @param {Array<Module>} directories
 */
function createSandbox(directory) {
    return __awaiter(this, void 0, void 0, function* () {
        const packageJson = directory['package.json'];
        if (!packageJson)
            throw new Error('Could not find package.json');
        const packageJsonPackage = JSON.parse(packageJson.content);
        const template = templates_1.getTemplate(packageJsonPackage, directory);
        const mainFile = findMainFile(directory, packageJsonPackage.main, template);
        if (!directory[mainFile]) {
            throw new Error(`Cannot find the specified entry point: '${mainFile}'. Please specify one in 'package.json#main' or create a file at the specified entry point.`);
        }
        // Give the sandboxModules to getDependencies to fetch which devDependencies
        // are used in the code
        const { modules, directories } = denormalize_1.default(directory);
        return {
            title: packageJsonPackage.title || packageJsonPackage.name,
            description: packageJsonPackage.description,
            tags: packageJsonPackage.keywords || [],
            modules,
            directories,
            externalResources: [],
            template,
            entry: mainFile,
        };
    });
}
exports.default = createSandbox;
//# sourceMappingURL=index.js.map